@@ -1,21 +1,20 @@
-# @keywords internal
-# @rdname other_predict
-# @param level A single numeric value between zero and one for the
-#  interval estimates.
-# @param std_error A single logical for wether the standard error should be
-#  returned (assuming that the model can compute it).
-# @inheritParams predict.model_fit
-# @method predict_confint model_fit
-# @export predict_confint.model_fit
-# @export
+#' @keywords internal
+#' @rdname other_predict
+#' @param level A single numeric value between zero and one for the
+#'  interval estimates.
+#' @param std_error A single logical for wether the standard error should be
+#'  returned (assuming that the model can compute it).
+#' @inheritParams predict.model_fit
+#' @method predict_confint model_fit
+#' @export predict_confint.model_fit
+#' @export
 predict_confint.model_fit <- function(object, new_data, level = 0.95, std_error = FALSE, ...) {
 
   if (is.null(object$spec$method$pred$conf_int))
-    stop("No confidence interval method defined for this ",
-         "engine.", call. = FALSE)
+    rlang::abort("No confidence interval method defined for this engine.")
 
   if (inherits(object$fit, "try-error")) {
-    warning("Model fit failed; cannot make predictions.", call. = FALSE)
+    rlang::warn("Model fit failed; cannot make predictions.")
     return(NULL)
   }
 
@@ -60,11 +59,10 @@ predict_confint <- function(object, ...)
 predict_predint.model_fit <- function(object, new_data, level = 0.95, std_error = FALSE, ...) {
 
   if (is.null(object$spec$method$pred$pred_int))
-    stop("No prediction interval method defined for this ",
-         "engine.", call. = FALSE)
+    rlang::abort("No prediction interval method defined for this engine.")
 
   if (inherits(object$fit, "try-error")) {
-    warning("Model fit failed; cannot make predictions.", call. = FALSE)
+    rlang::warn("Model fit failed; cannot make predictions.")
     return(NULL)
   }
 
