@@ -5,6 +5,7 @@
 #'  It translates generic parameters to their counterparts.
 #'
 #' @param x A model specification.
+#' @param engine The computational engine for the model (see `?set_engine`).
 #' @param ... Not currently used.
 #' @details
 #' `translate()` produces a _template_ call that lacks the specific
@@ -47,11 +48,13 @@ translate <- function(x, ...)
 #' @importFrom utils getFromNamespace
 #' @importFrom purrr list_modify
 #' @importFrom rlang lgl
+#' @rdname translate
 #' @export
+#' @export translate.default
 translate.default <- function(x, engine = x$engine, ...) {
   check_empty_ellipse(...)
   if (is.null(engine))
-    stop("Please set an engine.", call. = FALSE)
+    rlang::abort("Please set an engine.")
 
   mod_name <- specific_model(x)
 
@@ -59,7 +62,7 @@ translate.default <- function(x, engine = x$engine, ...) {
   x <- check_engine(x)
 
   if (x$mode == "unknown") {
-    stop("Model code depends on the mode; please specify one.", call. = FALSE)
+    rlang::abort("Model code depends on the mode; please specify one.")
   }
 
   if (is.null(x$method))
