@@ -4,6 +4,7 @@ library(parsnip)
 # ------------------------------------------------------------------------------
 
 context("boosted tree execution with xgboost")
+source("helper-objects.R")
 
 num_pred <- names(iris)[1:4]
 
@@ -11,10 +12,6 @@ iris_xgboost <-
   boost_tree(trees = 2, mode = "classification") %>%
   set_engine("xgboost")
 
-ctrl <- control_parsnip(verbosity = 1, catch = FALSE)
-caught_ctrl <- control_parsnip(verbosity = 1, catch = TRUE)
-quiet_ctrl <- control_parsnip(verbosity = 0, catch = TRUE)
-
 # ------------------------------------------------------------------------------
 
 test_that('xgboost execution, classification', {
@@ -101,10 +98,6 @@ bad_rf_reg <-
   boost_tree(mode = "regression") %>%
   set_engine("xgboost", sampsize = -10)
 
-ctrl <- list(verbosity = 1, catch = FALSE)
-caught_ctrl <- list(verbosity = 1, catch = TRUE)
-quiet_ctrl <- list(verbosity = 0, catch = TRUE)
-
 test_that('xgboost execution, regression', {
 
   skip_if_not_installed("xgboost")
