@@ -90,8 +90,8 @@ test_that("elapsed time parsnip mods", {
     set_engine("lm") %>%
     fit(mpg ~ ., data = mtcars)
 
-  expect_output(print(lm1), "Fit in:")
-  expect_output(print(lm2), "Fit in:")
+  expect_output(print(lm1), "Fit time:")
+  expect_output(print(lm2), "Fit time:")
   expect_true(!is.null(lm1$elapsed))
   expect_true(!is.null(lm2$elapsed))
 })
