@@ -7,23 +7,20 @@ library(tidyr)
 # ------------------------------------------------------------------------------
 
 context("logistic regression execution with glmnet")
+source("helper-objects.R")
 
-data("lending_club")
 lending_club <- head(lending_club, 200)
 lc_form <- as.formula(Class ~ log(funded_amnt) + int_rate)
 num_pred <- c("funded_amnt", "annual_inc", "num_il_tl")
 lc_bad_form <- as.formula(funded_amnt ~ term)
 lc_basic <- logistic_reg() %>% set_engine("glmnet")
 
-ctrl <- control_parsnip(verbosity = 1, catch = FALSE)
-caught_ctrl <- control_parsnip(verbosity = 1, catch = TRUE)
-quiet_ctrl <- control_parsnip(verbosity = 0, catch = TRUE)
-
 # ------------------------------------------------------------------------------
 
 test_that('glmnet execution', {
 
   skip_if_not_installed("glmnet")
+  skip_if(run_glmnet)
 
   expect_error(
     res <- fit_xy(
@@ -51,6 +48,7 @@ test_that('glmnet execution', {
 test_that('glmnet prediction, one lambda', {
 
   skip_if_not_installed("glmnet")
+  skip_if(run_glmnet)
 
   xy_fit <- fit_xy(
     logistic_reg(penalty = 0.1) %>% set_engine("glmnet"),
@@ -98,6 +96,7 @@ test_that('glmnet prediction, one lambda', {
 test_that('glmnet prediction, mulitiple lambda', {
 
   skip_if_not_installed("glmnet")
+  skip_if(run_glmnet)
 
   lams <- c(0.01, 0.1)
 
@@ -161,6 +160,7 @@ test_that('glmnet prediction, mulitiple lambda', {
 test_that('glmnet prediction, no lambda', {
 
   skip_if_not_installed("glmnet")
+  skip_if(run_glmnet)
 
   xy_fit <- fit_xy(
     logistic_reg() %>% set_engine("glmnet", nlambda =  11),
@@ -220,6 +220,7 @@ test_that('glmnet prediction, no lambda', {
 test_that('glmnet probabilities, one lambda', {
 
   skip_if_not_installed("glmnet")
+  skip_if(run_glmnet)
 
   xy_fit <- fit_xy(
     logistic_reg(penalty = 0.1)  %>% set_engine("glmnet"),
@@ -268,6 +269,7 @@ test_that('glmnet probabilities, one lambda', {
 test_that('glmnet probabilities, mulitiple lambda', {
 
   skip_if_not_installed("glmnet")
+  skip_if(run_glmnet)
 
   lams <- c(0.01, 0.1)
 
@@ -332,6 +334,7 @@ test_that('glmnet probabilities, mulitiple lambda', {
 test_that('glmnet probabilities, no lambda', {
 
   skip_if_not_installed("glmnet")
+  skip_if(run_glmnet)
 
   xy_fit <- fit_xy(
     logistic_reg()  %>% set_engine("glmnet"),
@@ -392,6 +395,7 @@ test_that('glmnet probabilities, no lambda', {
 test_that('submodel prediction', {
 
   skip_if_not_installed("glmnet")
+  skip_if(run_glmnet)
 
   vars <- c("female", "tenure", "total_charges", "phone_service", "monthly_charges")
   class_fit <-
